Enum pallet_asset_index::pallet::Call [−][src]
pub enum Call<T: Config> {
Show 13 variants
add_asset {
asset_id: T::AssetId,
units: T::Balance,
amount: T::Balance,
},
force_add_asset {
asset_id: T::AssetId,
units: T::Balance,
amount: T::Balance,
recipient: T::AccountId,
},
remove_asset {
asset_id: T::AssetId,
units: T::Balance,
recipient: Option<T::AccountId>,
},
force_remove_asset {
who: T::AccountId,
asset_id: T::AssetId,
units: T::Balance,
recipient: Option<T::AccountId>,
},
register_asset {
asset_id: T::AssetId,
availability: AssetAvailability,
},
set_deposit_range {
new_range: DepositRange<T::Balance>,
},
update_redemption_fees {
new_range: RedemptionFeeRange<T::BlockNumber>,
},
set_lockup_period {
lockup_period: T::BlockNumber,
},
set_metadata {
id: T::AssetId,
name: Vec<u8>,
symbol: Vec<u8>,
decimals: u8,
},
deposit {
asset_id: T::AssetId,
units: T::Balance,
},
withdraw {
amount: T::Balance,
},
complete_withdraw {},
unlock {},
// some variants omitted
}Expand description
Contains one variant per dispatchable that can be called by an extrinsic.
Variants
Callable by the governance committee to add new liquid assets to the index and mint the given amount IndexToken. The amount of PINT minted and awarded to the LP is specified as part of the associated proposal Caller’s balance is updated to allocate the correct amount of the IndexToken. The given amount of assets must already exist in the caller’s account, they are then transferred to the treasury account.
The Governance committee decides the tokens that comprise the index, as well as the allocation of each and their value.
Add liquid asset with root origin, see add_asset
Fields of force_add_asset
Dispatches transfer to move assets out of the index’s account, if a liquid asset is specified Callable by an admin.
Updates the index to reflect the removed assets (units) by burning index token accordingly. If the given asset is liquid, an xcm transfer will be dispatched to transfer the given units into the sovereign account of either:
- the given
recipientif provided - the caller’s account if
recipientisNone
Remove liquid asset with root origin
Fields of force_remove_asset
Registers a new asset in the index together with its availability
Only callable by the admin origin and for assets that are not yet registered.
Fields of register_asset
asset_id: T::AssetIdavailability: AssetAvailabilityUpdates the range for how much a deposit must be worth in index token in order to be accpedted. Only callable by the admin origin
Parameters:
new_range: The new valid range for deposits.
Fields of set_deposit_range
new_range: DepositRange<T::Balance>Updates the range for redemption fee
Only callable by the admin origin
Parameters:
new_range: The new valid range for redemption fee.
Fields of update_redemption_fees
new_range: RedemptionFeeRange<T::BlockNumber>Updates the lockup period
Only callable by the admin origin
Parameters:
lockup_period: how long will the depositing assets will be locked
Fields of set_lockup_period
lockup_period: T::BlockNumberForce the metadata for an asset to some value.
Origin must be ForceOrigin.
Any deposit is left alone.
id: The identifier of the asset to update.name: The user friendly name of this asset. Limited in length byStringLimit.symbol: The exchange symbol for this asset. Limited in length byStringLimit.decimals: The number of decimals this asset uses to represent one unit.
Emits MetadataSet.
Weight: O(N + S) where N and S are the length of the name and
symbol respectively.
Initiate a transfer from the user’s sovereign account into the index.
This will withdraw the given amount from the user’s sovereign account and mints PINT proportionally using the latest available price pairs
Starts the withdraw process for the given amount of PINT to redeem for a distribution of underlying assets.
All withdrawals undergo an unlocking period after which the assets can be withdrawn. A withdrawal fee will be deducted from the PINT being redeemed by the LP depending on how long the assets remained in the index. The remaining PINT will be burned to match the new NAV after this withdrawal.
The distribution of the underlying assets will be equivalent to the ratio of the liquid assets in the index.
Fields of withdraw
amount: T::BalanceAttempts to complete all currently pending redemption processes
started by the withdraw extrinsic.
This checks every pending withdrawal within PendingWithdrawal and
tries to close it. Completing a withdrawal will succeed if
following conditions are met:
- the
LockupPeriodhas passed since the withdrawal was initiated - the treasury can cover the asset transfer to the caller’s account, from which the
caller then can initiate an
Xcm::Withdrawto remove the assets from the PINT parachain entirely, if xcm transfers are supported.
NOTE: All individual withdrawals that resulted from “Withdraw”
will be completed separately, however, the entire record of pending
withdrawals will not be fully closed until the last withdrawal is
completed. This means that a single AssetWithdrawal will be closed
as soon as the aforementioned conditions are met, regardless of
whether the other AssetWithdrawals in the same PendingWithdrawal set
can also be closed successfully.
Fields of complete_withdraw
Updates the index token locks of the caller.
This removes expired locks and updates the caller’s index token balance accordingly.
Fields of unlock
Implementations
pub fn new_call_variant_add_asset(
asset_id: T::AssetId,
units: T::Balance,
amount: T::Balance
) -> Self
pub fn new_call_variant_add_asset(
asset_id: T::AssetId,
units: T::Balance,
amount: T::Balance
) -> Self
Create a call with the variant add_asset.
Create a call with the variant force_add_asset.
Create a call with the variant remove_asset.
Create a call with the variant force_remove_asset.
pub fn new_call_variant_register_asset(
asset_id: T::AssetId,
availability: AssetAvailability
) -> Self
pub fn new_call_variant_register_asset(
asset_id: T::AssetId,
availability: AssetAvailability
) -> Self
Create a call with the variant register_asset.
Create a call with the variant set_deposit_range.
pub fn new_call_variant_update_redemption_fees(
new_range: RedemptionFeeRange<T::BlockNumber>
) -> Self
pub fn new_call_variant_update_redemption_fees(
new_range: RedemptionFeeRange<T::BlockNumber>
) -> Self
Create a call with the variant update_redemption_fees.
Create a call with the variant set_lockup_period.
Create a call with the variant set_metadata.
Create a call with the variant deposit.
Create a call with the variant withdraw.
Create a call with the variant complete_withdraw.
Create a call with the variant unlock.